Learn R Programming

SigFuge (version 1.6.0)

SFpval: Calculate SigFuge $p$-value

Description

Function for computing significance of clustering $p$-value. $p$-value is obtained from sigclust, a simulation based procedure for testing significance of clustering in high dimension low sample size (HDLSS) data.

The SigClust hypothesis test is given:

  • H0: data generated from single Gaussian
  • H1: data not generated from single Gaussian

Usage

SFpval(data, normalize = 1, flag = 1)

Arguments

data
a $d x n$ matrix of read counts at $d$ positions for $n$ samples.
normalize
a $n x 1$ logical vector of flagged samples.
flag
a $n x 1$ logical vector of samples flagged as low expression. If flag == 1, default low expression cutoffs are applied to data. If flag == 0, no samples are flagged as low expression (equivalent to setting flag = zeros(n,1)).

Value

SFpval returns an object of class sigclust-class. Avaliable slots are described in detail in the sigclust package. Primarily, we make use of @pvalnorm.

Examples

Run this code
data(geneDepth)
SFout <- SFpval(geneDepth, normalize = 1, flag = 1)
SFout@pvalnorm

Run the code above in your browser using DataLab